@@ -1,4 +1,4 @@
 """This package organizes individual libraries employed by glymur."""
-from . import openjp2 as _openjp2
-from . import openjpeg as _openjpeg
+from . import openjp2 as openjp2
+from . import openjpeg as openjpeg
 from . import c
