@@ -1,5 +1,9 @@
+"""
+Test fixtures common to more than one test point.
+"""
 import re
 import sys
+import warnings
 
 import numpy as np
 
@@ -20,6 +24,28 @@ if glymur.lib.openjp2.OPENJP2 is not None:
         OPENJP2_IS_V2_OFFICIAL = True
 
 
+NO_READ_BACKEND_MSG = "Matplotlib with the PIL backend must be available in "
+NO_READ_BACKEND_MSG += "order to run the tests in this suite."
+
+try:
+    from matplotlib.pyplot import imread
+    NO_READ_BACKEND = False
+except ImportError:
+    NO_READ_BACKEND = True
+
+
+def read_image(infile):
+    """Read image using matplotlib backend.
+
+    Hopefully PIL(low) is installed as matplotlib's backend.  It issues
+    warnings which we do not care about, so suppress them.
+    """
+    with warnings.catch_warnings():
+        warnings.simplefilter("ignore")
+        data = imread(infile)
+    return data
+
+
 def mse(amat, bmat):
     """Mean Square Error"""
     diff = amat.astype(np.double) - bmat.astype(np.double)
@@ -36,28 +62,10 @@ def peak_tolerance(amat, bmat):
 
 def read_pgx(pgx_file):
     """Helper function for reading the PGX comparison files.
-
-    Open the file in ascii mode and read the header line.
-    Will look something like
-
-    PG ML + 8 128 128
-    PG%[ \t]%c%c%[ \t+-]%d%[ \t]%d%[ \t]%d"
     """
-    header = ''
-    with open(pgx_file, 'rb') as fptr:
-        while True:
-            char = fptr.read(1)
-            if char[0] == 10 or char == '\n':
-                pos = fptr.tell()
-                break
-            else:
-                if sys.hexversion < 0x03000000:
-                    header += char
-                else:
-                    header += chr(char[0])
+    header, pos = read_pgx_header(pgx_file)
 
-    header = header.rstrip()
-    tokens = re.split('\s', header)
+    tokens = re.split(r'\s', header)
 
     if (tokens[1][0] == 'M') and (sys.byteorder == 'little'):
         swapbytes = True
@@ -81,6 +89,29 @@ def read_pgx(pgx_file):
         nrows = int(tokens[4])
         ncols = int(tokens[3])
 
+    dtype = determine_pgx_datatype(signed, bitdepth)
+
+    shape = [nrows, ncols]
+
+    # Reopen the file in binary mode and seek to the start of the binary
+    # data
+    with open(pgx_file, 'rb') as fptr:
+        fptr.seek(pos)
+        data = np.fromfile(file=fptr, dtype=dtype).reshape(shape)
+
+    return(data.byteswap(swapbytes))
+
+
+def determine_pgx_datatype(signed, bitdepth):
+    """Determine the datatype of the PGX file.
+
+    Parameters
+    ----------
+    signed : bool
+        True if the datatype is signed, false otherwise
+    bitdepth : int
+        How many bits are used to make up an image plane.  Should be 8 or 16.
+    """
     if signed:
         if bitdepth <= 8:
             dtype = np.int8
@@ -96,12 +127,28 @@ def read_pgx(pgx_file):
         else:
             raise RuntimeError("unhandled bitdepth")
 
-    shape = [nrows, ncols]
+    return dtype
 
-    # Reopen the file in binary mode and seek to the start of the binary
-    # data
+
+def read_pgx_header(pgx_file):
+    """Open the file in ascii mode (not really) and read the header line.
+    Will look something like
+
+    PG ML + 8 128 128
+    PG%[ \t]%c%c%[ \t+-]%d%[ \t]%d%[ \t]%d"
+    """
+    header = ''
     with open(pgx_file, 'rb') as fptr:
-        fptr.seek(pos)
-        data = np.fromfile(file=fptr, dtype=dtype).reshape(shape)
+        while True:
+            char = fptr.read(1)
+            if char[0] == 10 or char == '\n':
+                pos = fptr.tell()
+                break
+            else:
+                if sys.hexversion < 0x03000000:
+                    header += char
+                else:
+                    header += chr(char[0])
 
-    return(data.byteswap(swapbytes))
+    header = header.rstrip()
+    return header, pos
